<?php
/**
 * @license MIT
 *
 * Modified by tokenoftrust on 22-January-2024 using {@see https://github.com/BrianHenryIE/strauss}.
 */

declare(strict_types=1);

namespace TOT\Dependencies\Sentry\Transport;

use TOT\Dependencies\Sentry\Event;

/**
 * This class contains the details of the sending operation of an event, e.g.
 * if it was sent successfully or if it was skipped because of some reason.
 *
 * @internal
 */
class Result
{
    /**
     * @var ResultStatus The status of the sending operation of the event
     */
    private $status;

    /**
     * @var Event|null The instance of the event being sent, or null if it
     *                 was not available yet
     */
    private $event;

    public function __construct(ResultStatus $status, ?Event $event = null)
    {
        $this->status = $status;
        $this->event = $event;
    }

    /**
     * Gets the status of the sending operation of the event.
     */
    public function getStatus(): ResultStatus
    {
        return $this->status;
    }

    /**
     * Gets the instance of the event being sent, or null if it was not available yet.
     */
    public function getEvent(): ?Event
    {
        return $this->event;
    }
}
