<?php

namespace TOT\Integrations\Sentry;

use TOT\Integrations\Sentry\SDK\Capture;
use TOT\Integrations\Sentry\SDK\Initiation;
use TOT\Settings;

/**
 * Bridge pattern to use Sentry SDK or Sentry API on the future
 */
class Sentry
{
	private static $inst = null;

	private $dsn;

	/**
	 * @var Initiation|null
	 */
	private $initiation = null;

	/**
	 * @var Capture|null
	 */
	private $capture = null;

	/**
	 * Singleton pattern
	 * @return self
	 */
	public static function inst()
	{
		if (is_null(self::$inst)) {
			self::$inst = new self();
		}

		return self::$inst;
	}

	public static function captureRefreshedDSN()
	{
		self::$inst = null;
		return self::inst()->captureInfo('DSN is refreshed');
	}

	public function captureInfo($head, $log = '')
	{
		$this->capture && $this->capture->info($head, $log);
	}

	public function captureWarning($head, $log = '')
	{
		$this->capture && $this->capture->warning($head, $log);
	}

	public function captureError($head, $log = '')
	{
		$this->capture && $this->capture->error($head, $log);
	}

	private function __construct()
	{
		if ($this->isActive()) {
			$this->includeSDKClasses();
			$this->factorySDKObjs();
		}
	}

	private function isActive()
	{
		return (bool)$this->getDSN();
	}

	private function getDSN()
	{
		if (is_null($this->dsn)) {
			$this->dsn = Settings::get_setting('tot_field_sentry_dsn');
		}

		return $this->dsn;
	}

	private function includeSDKClasses()
	{
		require_once __DIR__ . '/../../dependencies/autoload.php';
		require_once __DIR__ . '/sdk/class-initiation.php';
		require_once __DIR__ . '/sdk/class-capture.php';
	}

	private function factorySDKObjs()
	{
		$this->initiation = Initiation::inst($this->getDSN());
		$this->capture = Capture::inst();
		$this->initiation->doInit();
	}
}