<?php
namespace TOT\Integrations\WooCommerce;
class Donations {

	private static $tables = [
		[
			"label" => "All months",
			"date_query" => null,
			"orders" => null,
			"sum" => 0
		],
		[
			"label" => "The current month",
			"date_query" => array(
				array(
					'column' => 'post_date_gmt',
					'after'  => '1 month ago',
				),
			),
			"orders" => null,
			"sum" => 0
		],
		[
			"label" => "Last month",
			"date_query" => array(
				array(
					'column' => 'post_date_gmt',
					'after'  => '2 months ago',
				),
			),
			"orders" => null,
			"sum" => 0
		],
		[
			"label" => "Two months ago",
			"date_query" => array(
				array(
					'column' => 'post_date_gmt',
					'after'  => '3 months ago',
				),
			),
			"orders" => null,
			"sum" => 0
		]
	];

	public static function get_tables()
	{
		$order_statuses = wc_get_order_statuses();
		unset(
			$order_statuses['wc-refunded'],
			$order_statuses['wc-pending'],
			$order_statuses['wc-cancelled'],
			$order_statuses['wc-failed']
		);
		$tables = self::$tables;

		foreach ($tables as $key => $table) {

			// no need to fetch the data again
			if ( is_array($table['orders']) ) {
				continue;
			}

			$args = [
				'post_type' => 'shop_order',
				'post_status' => array_keys($order_statuses),
				'posts_per_page' => -1,
				'meta_query' => array(
					array(
						'key' => 'tot_donation_value',
						'value' => '0',
						'compare' => '>'
					)
				)
			];
			if ($table['date_query']) {
				$args['date_query'] = $table['date_query'];
			}

			$table['orders'] = get_posts($args);
			$table['sum'] = array_reduce($table['orders'], function ($total, $order)
			{
				$total += get_post_meta($order->ID, 'tot_donation_value', true);
				return $total;
			}, 0);

			$tables[$key] = $table;
		}

		return self::$tables = $tables;
	}

	public function __construct() {
		add_action('init', array($this, 'handle_export_table'));
	}

	public function handle_export_table() {
		if (isset($_GET['tot_export_table']) && is_numeric($_GET['tot_export_table']))
		{
			$this->export_table_as_csv();
		}
	}
	public function export_table_as_csv() {
		$table_no = $_GET['tot_export_table'];
		$tables = self::get_tables();
		if (!isset($tables[$table_no])) {
			return;
		}
		$table = $tables[$table_no];

		// Define CSV filename
		$filename = 'tot_donations_' .  time() . '.csv';

		// Set CSV headers
		$header_row = ['Date', 'Order number', 'Charitable amount', 'Order Url'];

		// Create a temporary file
		$temp_file = tmpfile();

		// Write CSV headers to the temporary file
		fputcsv($temp_file, $header_row);

		// Write table data rows to the temporary file
		foreach ($table['orders'] as $order) {
			fputcsv($temp_file, [
				$order->post_date,
				$order->ID,
				'$'. get_post_meta($order->ID, 'tot_donation_value', true),
				get_edit_post_link($order->ID, '')
			]);
		}

		// Seek to the beginning of the temporary file
		fseek($temp_file, 0);

		// Set appropriate headers for file download
		header('Content-Type: text/csv');
		header('Content-Disposition: attachment; filename=' . $filename);

		// Output the contents of the temporary file
		fpassthru($temp_file);

		// Close and remove the temporary file
		fclose($temp_file);
		exit();
	}
}